/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.mo.components.bc.soap;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_MAX_SIZE;
import static org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock.HTTP_SERVER_THREAD_POOL_MIN_SIZE;

import java.io.ByteArrayOutputStream;
import java.util.List;
import java.util.StringTokenizer;

import org.junit.Test;
import org.ow2.petals.admin.jmx.JMXClientConnection;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.MonitoringSubFunction;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.MonitoringSubFunctionBadArgumentNumberException;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.MonitoringSubFunctionException;
import org.ow2.petals.cli.extension.command.monitoring.mo.api.exception.MonitoringSubFunctionMissingOptionsException;
import org.ow2.petals.cli.extension.command.monitoring.mo.components.framework.Constants;
import org.ow2.petals.cli.extension.command.monitoring.mo.util.SimpleShell;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.mock.PetalsJmxApiFactoryMock;
import org.ow2.petals.jmx.api.mock.monitoring.component.soap.PetalsBcSoapMonitoringServiceClientMock;

/**
 * Unit tests of {@link HttpThreadPool}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class HttpThreadPoolTest extends AbstractTestCase {

    /**
     * Test the method 'execute()' against argument management, where:
     * <ul>
     * <li>no option is provided</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: an error occurs about bad argument number.
     * </p>
     */
    @Test
    public void testExecute_Error_00() throws MonitoringSubFunctionException {

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        try {
            monitoringSubFunction.execute(new String[] {});
            fail(MonitoringSubFunctionMissingOptionsException.class.getName() + " is not thrown.");
        } catch (final MonitoringSubFunctionMissingOptionsException e) {
            // Expected exception
            assertTrue(
                    "Error label is missing.",
                    e.getMessage().startsWith(
                            MonitoringSubFunctionMissingOptionsException.MISSING_OPTIONS));

            final List missingOptions = e.getMissingOptions();
            assertEquals("More than one missing options", 1, missingOptions.size());
        }
    }

    /**
     * Test the method 'execute()' against argument management, where:
     * <ul>
     * <li>an unregonized option is provided</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: an error occurs about bad argument number.
     * </p>
     */
    @Test
    public void testExecute_Error_01() throws MonitoringSubFunctionException {

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        try {
            monitoringSubFunction.execute(new String[] { "-z" });
            fail(MonitoringSubFunctionBadArgumentNumberException.class.getName()
                    + " is not thrown.");
        } catch (final MonitoringSubFunctionBadArgumentNumberException e) {
            // Expected exception
            assertTrue(
                    "Error label is missing.",
                    e.getMessage()
                            .startsWith(
                                    MonitoringSubFunctionBadArgumentNumberException.BAD_NUMBER_OF_ARGUMENTS_OR_INCOMPATIBLE_ARGUMENTS));
        }
    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided does not exist.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: An error occurs about the unexisting component
     * </p>
     */
    @Test
    public void testExecute_00() throws MonitoringSubFunctionException, ConnectionErrorException {

        this.expectedEx.expect(MonitoringSubFunctionException.class);
        this.expectedEx.expectMessage(String.format(Constants.ERROR_MSG_COMP_DOES_NOT_EXIST,
                PetalsBcSoapMonitoringServiceClientMock.IDENTIFIER_FOR_AN_UNEXISTING_COMPONENT));

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.IDENTIFIER_FOR_AN_UNEXISTING_COMPONENT });
    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>error occurs getting HTTP thread pool value.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: An error occurs
     * </p>
     */
    @Test(expected = MonitoringSubFunctionException.class)
    public void testExecute_01() throws MonitoringSubFunctionException, ConnectionErrorException {

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.IDENTIFIER_FOR_COMPONENT_WITH_ERROR });
    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the max
     * allocated threads of HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the max allocated threads of HTTP
     * server thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_02() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = null;
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertFalse(
                "the metric value associated to the max allocated threads of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the current
     * allocated threads of HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the current allocated threads of HTTP
     * server thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_03() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = null;
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertFalse(
                "the metric value associated to the current allocated threads of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the current
     * idle threads of HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the current idle threads of HTTP
     * server thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_04() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = null;
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertFalse(
                "the metric value associated to the current idle threads of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the max idle
     * threads of HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the max idle threads of HTTP server
     * thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_05() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = null;
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertFalse(
                "the metric value associated to the max idle threads of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the max
     * enqueued request number in HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the max enqueued request number in
     * HTTP server thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_06() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = null;
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertFalse(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the current
     * enqueued request number in HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the current enqueued request number in
     * HTTP server thread pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_07() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = null;
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is ot displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertFalse(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the max size of
     * HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the max size of HTTP server thread
     * pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_08() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = null;
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertFalse(
                "the metric value associated to the max size of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertTrue(
                "the metric value associated to the min size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>a null value is returned for the metric associated to the min size of
     * HTTP server thread pool,</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric value associated to the min size of HTTP server thread
     * pool is not returned,</li>
     * <li>other values are correctly displayed.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_09() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long.valueOf(123);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = null;
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(123);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertTrue(
                "the metric value associated to the max allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current allocated threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_MAX));
        assertTrue(
                "the metric value associated to the current idle threads of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_IDLE_THREAD_CURRENT));
        assertTrue(
                "the metric value associated to the max size of HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_MAX_SIZE));
        assertFalse(
                "the metric value associated to the min size of HTTP server thread pool is displayed",
                output.contains(HttpThreadPool.HEADER_MIN_SIZE));
        assertTrue(
                "the metric value associated to the current enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT));
        assertTrue(
                "the metric value associated to the max enqueued request number in the HTTP server thread pool is not displayed",
                output.contains(HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX));

    }

    /**
     * Test the method 'execute()' against processing, where:
     * <ul>
     * <li>a connection to a Petals ESB container is established,</li>
     * <li>the BC SOAP identifier provided exists,</li>
     * <li>no null value is returned for metric,</li>
     * <li>no error will occur.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results:
     * <ul>
     * <li>no error,</li>
     * <li>the metric values are returned and they have the right value.</li>
     * </ul>
     * </p>
     */
    @Test
    public void testExecute_10() throws MonitoringSubFunctionException, ConnectionErrorException {

        final ByteArrayOutputStream errBAOS = new ByteArrayOutputStream();
        final ByteArrayOutputStream outBAOS = new ByteArrayOutputStream();

        final MonitoringSubFunction monitoringSubFunction = new HttpThreadPool();
        monitoringSubFunction.setShell(new SimpleShell(outBAOS, errBAOS));
        JMXClientConnection.createJMXClient(PetalsJmxApiFactoryMock.HOST_NO_ERROR,
                PetalsJmxApiFactoryMock.DEFAULT_PORT, PetalsJmxApiFactoryMock.DEFAULT_USERNAME,
                PetalsJmxApiFactoryMock.DEFAULT_PASSWORD);
        final long httpServerThreadPoolAllocatedThreadCurrent = 123;
        final long httpServerThreadPoolAllocatedThreadMax = 167;
        final long httpServerThreadPoolIdleThreadCurrent = 2;
        final long httpServerThreadPoolIdleThreadMax = 7;
        final long httpServerThreadPoolEnqueuedRequestCurrent = 1;
        final long httpServerThreadPoolEnqueuedRequestMax = 3;
        final long httpServerThreadPoolMinSize = 5;
        final long httpServerThreadPoolMaxSize = 25;
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT = Long
                .valueOf(httpServerThreadPoolAllocatedThreadCurrent);
        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX = Long
                .valueOf(httpServerThreadPoolAllocatedThreadMax);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT = Long
                .valueOf(httpServerThreadPoolIdleThreadCurrent);
        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX = Long.valueOf(httpServerThreadPoolIdleThreadMax);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT = Long
                .valueOf(httpServerThreadPoolEnqueuedRequestCurrent);
        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX = Long
                .valueOf(httpServerThreadPoolEnqueuedRequestMax);
        HTTP_SERVER_THREAD_POOL_MIN_SIZE = Long.valueOf(httpServerThreadPoolMinSize);
        HTTP_SERVER_THREAD_POOL_MAX_SIZE = Long.valueOf(httpServerThreadPoolMaxSize);
        monitoringSubFunction.execute(new String[] {
                "-" + HttpThreadPool.COMPONENT_NAME_SHORT_OPTION,
                PetalsBcSoapMonitoringServiceClientMock.DEFAULT_COMPONENT_IDENTIFIER });

        final String error = errBAOS.toString();
        final String output = outBAOS.toString();
        assertTrue("An error occurs", error.isEmpty());
        assertFalse("No output", output.isEmpty());

        boolean isMissingHttpServerThreadPoolAllocatedThreadCurrent = true;
        boolean isMissingHttpServerThreadPoolAllocatedThreadMax = true;
        boolean isMissingHttpServerThreadPoolIdleThreadCurrent = true;
        boolean isMissingHttpServerThreadPoolIdleThreadMax = true;
        boolean isMissingHttpServerThreadPoolEnqueuedRequestMax = true;
        boolean isMissingHttpServerThreadPoolEnqueuedRequestCurrent = true;
        boolean isMissingHttpServerThreadPoolMinSize = true;
        boolean isMissingHttpServerThreadPoolMaxSize = true;
        final StringTokenizer strTokenizer = new StringTokenizer(output);
        while (strTokenizer.hasMoreElements()) {
            final StringTokenizer metricTokenizer = new StringTokenizer(strTokenizer.nextToken(),
                    ":");
            final String metricLabel = metricTokenizer.nextToken();
            assertNotNull("missing metric label", metricLabel);
            final String metricValue = metricTokenizer.nextToken();
            assertNotNull("missing metric value", metricValue);
            if (HttpThreadPool.HEADER_ALLOCATED_THREAD_CURRENT
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the current allocated threads of HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_CURRENT, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolAllocatedThreadCurrent = false;
            } else if (HttpThreadPool.HEADER_ALLOCATED_THREAD_MAX
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the max allocated threads of HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_ALLOCATED_THREAD_MAX, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolAllocatedThreadMax = false;
            } else if (HttpThreadPool.HEADER_IDLE_THREAD_MAX
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the max idle threads of HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_MAX, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolIdleThreadMax = false;
            } else if (HttpThreadPool.HEADER_IDLE_THREAD_CURRENT
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the current idle threads of HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_IDLE_THREAD_CURRENT, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolIdleThreadCurrent = false;
            } else if (HttpThreadPool.HEADER_ENQUEUED_REQUEST_MAX
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the max enqueued request in the HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_MAX, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolEnqueuedRequestMax = false;
            } else if (HttpThreadPool.HEADER_ENQUEUED_REQUEST_CURRENT
                    .equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the current enqueued request into the HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_ENQUEUED_REQUEST_CURRENT, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolEnqueuedRequestCurrent = false;
            } else if (HttpThreadPool.HEADER_MIN_SIZE.equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the min size of the HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_MIN_SIZE, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolMinSize = false;
            } else if (HttpThreadPool.HEADER_MAX_SIZE.equals(metricLabel)) {
                assertEquals(
                        "invalid metric value associated to the max size of the HTTP server thread pool",
                        HTTP_SERVER_THREAD_POOL_MAX_SIZE, Long.valueOf(metricValue));
                isMissingHttpServerThreadPoolMaxSize = false;
            } else {
                fail("Unexpected metric");
            }
        }
        assertFalse(
                "The metric value associated to the current allocated threads of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolAllocatedThreadCurrent);
        assertFalse(
                "The metric value associated to the max allocated threads of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolAllocatedThreadMax);
        assertFalse(
                "The metric value associated to the current idle threads of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolIdleThreadCurrent);
        assertFalse(
                "The metric value associated to the max idle threads of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolIdleThreadMax);
        assertFalse(
                "The metric value associated to the current enqueued request into the HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolEnqueuedRequestCurrent);
        assertFalse(
                "The metric value associated to the max enqueued request into the HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolEnqueuedRequestMax);
        assertFalse(
                "The metric value associated the max size of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolMaxSize);
        assertFalse(
                "The metric value associated the min size of HTTP server thread pool is missing",
                isMissingHttpServerThreadPoolMinSize);
    }
}
